@@ -145,7 +145,7 @@ class EntityList:
             stop_time,
             granularity=0,
             return_type=Constants.RETURN_PANDAS,
-            transformations=None):
+            transformations=[]):
         """
         Get the data of all tags in the list between the given start_time and
         stop_time for the given granularity
